Monty Python's Flying Circus: Just the Words - Episode 14

# Episode Fourteen

'Face the Press'
New cooker sketch
Tobacconists (prostitute advert)
The Ministry of Silly Walks
The Piranha brothers

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| A man in evening dress, sitting in a cage at the zoo.
Voice Over | And now for something completely different.
| Pan to show 'It's' man in next cage.
It's Man | It's...
| Animated titles. Cut to studio: interviewer in chair. SUPERIMPOSED CAPTION: 'FACE THE PRESS'
Interviewer | Hello. Tonight on 'Face the Press' we're going to examine two different views of contemporary things. On my left is the Minister for Home Affairs (cut to minister completely in drag and a moustache) who is wearing a striking organza dress in pink tulle, with matching pearls and a diamante collar necklace. (soft fashion-parade music starts to play in background) The shoes are in brushed pigskin with gold clasps, by Maxwell of Bond Street. The hair is by Roger, and the whole ensemble is crowned by a spectacular display of Christmas orchids. And on my right - putting the case against the Government - is a small patch of brown liquid ... (cut to patch of liquid on seat of chair) which could be creosote or some extract used in industrial varnishing. (cut back to interviewer) Good evening. Minister, may I put the first question to you? In your plan, 'A Better Britain For Us', you claimed that you would build 88,000 million, billion houses a year in the Greater London area alone. In fact, you've built only three in the last fifteen years. Are you a bit disappointed with this result?
Minister | No, no. I'd like to answer this question if I may in two ways. Firstly in my normal voice and then in a kind of silly high-pitched whine... You see housing is a problem really...
| Cut back to the interviewer. The minister is heard droning on in the background. The soft fashion-parade music starts again.
Interviewer | Well, while the minister is answering this question I'd just like to point out the minister's dress has been made entirely by hand from over three hundred pieces of Arabian shot silk (at this point we can hear the minister's high-pitched whine beneath the fashion music) especially created for the minister by Vargar's of Paris. The low slim-line has been cut off-the-shoulder to heighten the effect of the minister's fine bone structure. Well I think the minister is coming to the end of his answer now so let's go back over and join the discussion. Thank you very much minister. Today saw the appointment of a new head of...
Minister | Don't I say any more?
Interviewer | No fear! Today saw the appointment of a new head of Allied Bomber Command - Air Chief Marshal Sir Vincent 'Kill the Japs' Forster. He's in our Birmingham studio...
| Cut to close-up on what appears to be a monitor with Sir Vincent on it in outrageous drag, heavy lipstick, big bust etc. - Draped on a chaise-longue. A small black boy is fanning him.
Sir Vincent | Hello Sailors! Listen, guess what. The Minister of Aviation has made me head of the RAF Ola Pola.
| As he talks we zoom out quickly from the set to reveal it is not a monitor in the studio but a TV set in a G-plan type sitting room. A housewife (Mrs Pinnet) sits watching, wearing an apron and a scarf and with her hair in curlers. The doorbell sounds. She switches the TV off and answers the door which opens straight into the living room. There in the street stands a truly, amazing figure of fun. A man in a bowler hat with an axe sticking out of it, big red joke nose, illuminated bow tie that revolves, joke broad shoulders, clown's check jacket, long johns with sock suspenders, heavy army boots and leading a goat with a hat. Close-up.
Man | Hello. Mrs Rogers?
Mrs Pinnet | No. Ooh I must be in the wrong house,
| She shuts the door on him and we follow her as she crosses the room. She climbs out of the window. Back yard of terraced house. She scrambles over a quite high dividing wall into next door and starts to scramble into next-door window. Interior of a more cluttered working-dass sitting-room. There is a TV in there with Sir Vincent still camping it up.
Sir Vincent | So from now on we're going to do things my way. For a start David Hockney is going to design the bombs. And I've seen the plans...
| The doorbell rings.
Mrs Pinnet | That must be the new gas cooker.
| She switches the TV off. Immediate thunderous epic music. SUPERIMPOSED CAPTION: (in stone lettering, as for Ben Hur) 'NEW COOKER SKETCH' Both caption and music switch off suddenly as she opens the door. Outside the door are two gas men with a new cooker.
First Gas Man | Morning. Mrs G. Crump?
Mrs Pinnet | No - Mrs G. Pinnet.
First Gas Man | This is 46 Egernon Crescent?
Mrs Pinnet | No - Road. Egernon Road.
First Gas Man | (looks at a bit of paper) Road, yes, says here. Yeah. Right, could I speak to Mrs G. Crump please?
Mrs Pinnet | Oh there's nobody here of that name. It's Mrs G. Pinnet. 46 Egernon Road.
First Gas Man | Well it says 'Crump' here. Don't it, Harry?
Second Gas Man | Yeah - it's on the invoice.
First Gas Man | Yeah, definitely Crump.
Mrs Pinnet | Well there must have been a mistake, because the address is right, and that's definitely the cooker I ordered - a blue and white CookEasi.
First Gas Man | Well you can't have this. This is Crump.
Mrs Pinnet | Oh dear, what are we going to do?
First Gas Man | Well I don't know. What we can do for you is take it back to the Depot, get a transfer slip from Crump to Pinnet, and put it on a special delivery.
Second Gas Man | Yeah - that's best. We'll special it for you, we'll get it down there today and you'll get it back in ten weeks.
Mrs Pinnet | Ten weeks! Blimey, can't you just leave this one?
First Gas Man | What this? What leave it here? (they seem thunderstruck)
Mrs Pinnet | Yes.
First Gas Man | Well I dunno. I suppose we could.
Second Gas Man | Oh, but she'd have to fill out a temporary despatch note.
First Gas Man | Yeah we could leave it on a temporary despatch note.
Mrs Pinnet | Well that's sorted out then. What a mess, isn't it.
First Gas Man | I know, it's ridiculous really, but there you are. Glad we could be of such a help. Right, would you sign it down there please, Mrs Crump?
Mrs Pinnet | Pinnet.
First Gas Man | Pinnet. Listen, just for the books make it a bit easier, could you sign it Crump-Pinnet.
Mrs Pinnet | Right. (she signs)
First Gas Man | Right. Thank you very much, dear. The cooker's yours. Right. Thank you very much, dear. Right. (they push it just inside the door and move off) Sorry about the bother... but there you are ... you know ... cheerio!
Second Gas Man | Cheerio, Mrs Crump!
Mrs Pinnet | Heh, excuse me! Cooey! Er, can you put it in the kitchen?
First Gas Man | (coming back) You what?
Mrs Pinnet | Well I can't cook on it unless it's connected up.
First Gas Man | Oh we didn't realize you had an installation invoice.
Second Gas Man | An MI.
First Gas Man | No, we can't touch it without an MI, you see.
Second Gas Man | Or an R16.
Third Gas Man | (who is suddenly revealed behind the two of them) If it's a special.
Second Gas Man | Nah - it's not special ... the special's back at the Depot.
First Gas Man | No, the special's the same as installation invoice.
Third Gas Man | So it's an R16.
Mrs Pinnet | What's an installation invoice?
First Gas Man | A pink form from Reading.
Mrs Pinnet | Oh - we wondered what that was. Now these are the forms. (she produces a large wad of papers, sorts through and products a pink form which she hands to them)
First Gas Man | That's the one, love. Yeah, this should be all I need. Hang on. This is for Pinnet. Mrs G. Pinnet.
Mrs Pinnet | That's right. I'm Mrs G. Pinnet.
First Gas Man | Well we've got Crump-Pinnet on the invoice.
Mrs Pinnet | Well shall I sign it Crump-Pinnet then?
First Gas Man | No, no, no - not an MI - no.
Second Gas Man | No - that's from Area Service at Reading.
Fourth Gas Man | (suddenly revealed) No, Cheltenham isn't it?
Second Gas Man | No, not this side of the street.
Mrs Pinnet | Look I just want it connected up.
| Much doubtfulness.
Third Gas Man | What about London Office?
First Gas Man | Well they haven't got the machinery.
Second Gas Man | Not now.
Fifth Gas Man | (suddenly, revealed) What! The Hounslow Depot?
Fourth Gas Man | No - they're still on standard pressure.
Sixth Gas Man | (suddenly revealed) Same with Twickenham.
Mrs Pinnet | But surely they can connect up a gas cooker?
First Gas Man | Oh yeah, we could connect it up, love, but not unless it's an emergency.
Mrs Pinnet | But this is an emergency.
First Gas Man | No it's not. An emergency is 290... 'where there is actual or apparent loss of combustible gaseous substances'.
Second Gas Man | Yeah, it's like a leak.
| Seventh gas man is revealed.
Seventh Gas Man | Yeah, or a 478.
Third Gas Man | No - that's valve adjustment.
Mrs Pinnet | But there can't be a leak unless you've connected it up.
First Gas Man | No, quite. We'd have to turn it on.
Mrs Pinnet | Well can't you turn it on and connect it up?
First Gas Man | No. But what we can do, and this is between you and me, I shouldn't really be telling you this, we'll turn your gas on, make a hole in your pipe, you ring Hounslow emergency, they'll be around here in a couple of days.
Mrs Pinnet | What, a house full of gas! I'll be dead by then
First Gas Man | Oh well, in that case you'd have the South East Area Manager round here like a shot.
Mrs Pinnet | Really?
First Gas Man | Ah yes. 'One or more persons overcome by fumes', you'd have Head Office, Holbom, round here.
Mrs Pinnet | Really?
First Gas Man | Yes. That's murder you see.
Second Gas Man | Or suicide.
Fifth Gas Man | No. That's S42.
Second Gas Man | Oh.
| Eighth gas man is revealed.
Eighth Gas Man | Still? I thought it was Hainault.
Fifth Gas Man | No - Central area and Southall Marketing Division, they're both on the S42 now.
Mrs Pinnet | And they'd be able to connect it up?
First Gas Man | Oh - they'd do the lot for you, love.
Mrs Pinnet | And they'd come round this afternoon?
First Gas Man | ... Well what is it now... 11:30... murder... they'll be round here by two.
Mrs Pinnet | Oh well that's wonderful.
First Gas Man | Oh well, right love, if you'd like to lie down here.
Mrs Pinnet | All right. (she does so)
First Gas Man | Okay Harry.
Second Gas Man | Okay. Gas on.
First Gas Man | (holding a gas pipe to her mouth) Right, deep breaths love. Ring Head Office would you Norman...
Fourth Gas Man | Shall I go through maintenance?
Fifth Gas Man | No, you'd better go through Deptford maintenance.
Sixth Gas Man | Peckham's on a 207 .... .
Voices | ... that's LeWisham. What about Tottenham? No that would be a 5.4.. what about Lewisham? It's central isn't it? Or Ruislip...
| The camera pans along line of gas men all turning to each other and muttering incomprehensible technicalities, the line stretches across to front door. Line continues outside in street and goes into animation sequences which eventually brings us to a close-up on a small ad, which is one of many on the door of a small newsagent's shop. A shabby man is running an evil eye down the adverts, puzzling, looking for something. He walks up to the counter. He has a reflex wink.
Customer | Good morning.
Shopkeeper | Good morning, sir. Can I help you?
Customer | Help me? Yeah, I'll say you can help me.
Shopkeeper | Yes, sir?
Customer | I come about your advert - 'Small white pussy cat for sale. Excellent condition'.
Shopkeeper | Ah. You wish to buy it?
Customer | That's right. Just for the hour. Only I aint gonna pay more'n a fiver cos it aint worth it.
Shopkeeper | Well it's come from a very good home - it's house trained.
Customer | (long think, goes to door, looks at ads again) Chest of drawers? Chest. Drawers. I'd like some chest of drawers please.
Shopkeeper | Yes, sir.
Customer | Does it go?
Shopkeeper | Er, it's over there in the corner. (indicates a wooden chest of drawers)
Customer | Oh. (goes to door, runs his finger down the list of adverts) Pram for sale. Any offers. I'd like a bit of pram please.
Shopkeeper | Ah yes, sir. That's in good condition.
Customer | Oh good, I like them in good condition, eh? Eh?
Shopkeeper | Yes, here it is you see. (picks up pram)
Customer | (looks, pauses, goes back to the door, runs finger again) Babysitter. No, it's a babysitter. Babysitter?
Shopkeeper | Babysitter.
Customer | Babysitter - I don't want a babysitter. Be a blood donor - that's it. I'd like to give some blood please, argh! (shopkeeper shakes head) Oh spit. Which one is it? (shopkeeper slips him a card from out of his pocket) Blond prostitute will indulge in any sexual activity for four quid a week. What does that mean?
| A city gent comes into shop. He has a silly walk and keeps doing little jumps and then three long paces without moving the top of his body. He buys a paper, then we follow him as he leaves the shop.
City Gent | 'Times' please.
Shopkeeper | Oh yes sir, here you are.
City Gent | Thank you.
Shopkeeper | Cheers.
| The city gent leaves the shop, from which we see a line of gas men stretching back up the road to Mrs Pinnet's house, and walks off in an indescribably silly manner. Cut to him proceeding along Whitehall, and into a building labelled 'Ministry of Silly Walks '. Inside the building he passes three other men, each walking in their own eccentric way. Cut to an office; a man is sitting waiting. The city gent enters eccentrically.
Minister | Good morning. I'm sorry to have kept you waiting, but I'm afraid my walk has become rather sillier recently, and so it takes me rather longer to get to work. (sits at desk) Now then, what was it again?
Man | Well sir, I have a silly walk and I'd like to obtain a Government grant to help me develop it.
Minister | I see. May I see your silly walk?
Man | Yes, certainly, yes.
| He gets up and does a few steps, lifting the bottom part of his left leg sharply at every alternate pace. He stops.
Minister | That's it, is it?
Man | Yes, that's it, yes.
Minister | It's not particularly silly, is it? I mean, the right leg isn't silly at all and the left leg merely does a forward aerial half turn every alternate step.
Man | Yes, but I think that with Government backing I could make it very silly.
Minister | (rising) Mr Pudey, (he walks about behind the desk in a very silly fashion) the very real problem is one of money. I'm afraid that the Ministry of Silly Walks is no longer getting the kind of support it needs. You see there's Defense, Social Security, Health, Housing, Education, Silly Walks ... they're all supposed to get the same. But last year, the Government spent less on the Ministry of Silly Walks than it did on National Defence. Now we get £348,000,000 a year, which is supposed to be spent on all our available products. (he sits down) Coffee?
Man | Yes please.
Minister | (pressing intercorn) Now Mrs Two-Lumps, would you bring us in two coffees please?
Intercom Voice | Yes, Mr Teabag.
Minister | ... Out of her mind. Now the Japanese have a man who can bend his leg back over his head and back again with every single step. While the Israelis... ah, here's the coffee.
| Enter secretary with tray with two cups on it. She has a particularly jerky silly walk which means that by the time she reaches the minister there is no coffee left in the cups. The minister has a quick look in the cups, and smiles understandingly.
Minister | Thank you - lovely. (she exits still carrying tray and cups) You're really interested in silly walks, aren't you?
Man | Oh rather. Yes.
Minister | Well take a look at this, then.
| He products a projector from beneath his desk already spooled up and plugged in. He flicks a switch and it beams onto the opposite wall. The film shows a sequence of six old-fashioned silly walkers. The film is old silent-movie type, scratchy, jerky and 8mm quality. All the participants wear 1900's type costume. One has huge shoes with soles a foot thick, one is a woman, one has. very long 'Little Tich' shoes. Cut back to office. The minister hurls the projector away. Along with papers and everything else on his desk. He leans foward.
Minister | Now Mr Pudey. I'm not going to mince words with you. I'm going to offer you a Research Fellowship on the Anglo-French silly walk.
Man | La Marche Futile?
| Cut to two Frenchmen, wearing striped jerseys and berets, standing in a field with a third man who is entirely covered by a sheet.
First Frenchman | Bonjour ... et maintenant ... comme d'habitude, au sujet du Le Marché Commun. Et maintenant, je vous presente, encore une fois, mon ami, le pouf célèbre, Jean-Brian Zatapathique. (he removes his moustache and sticks it onto the other Frenchman)
Second Frenchman | Merci, mon petit chou-chou Brian Trubshawe. Et maintenant avec les pieds à droite, et les pieds au gauche, et maintenant l'Anglais-Française Marche Futile, et voilà
| They unveil the third man and walk off. He is facing to camera left and appears to be dressed as a city gent; then he turns about face and we see on his right half he is dressed au style francais. He moves off into the distance in eccentric speeded-up motion.
Voice Over | And now a choice of viewing on BBC Television. (cut to BBC world symbol) Just started on BBC2, the semi final of Episode 3 of 'Kierkegaard's Journals', staring Richard Chamberlain, Peggy Mount and Billy Bremner, and on BBC1, 'Ethel the Frog'
| Stirring music - 'This Week' type. SUPERIMPOSED CAPTION: 'ETHEL THE FROG' Cut to Presenter at desk in usual grey suit and floral tie.
Presenter | Good evening. On 'Ethel the Frog' tonight we look at violence. The violence of British Gangland. Last Tuesday a reign of terror was ended when the notorious Piranha brothers, Doug and Dinsdale (photo of same), after one of the most extraordinary trials in British legal history, were sentenced to four hundred years imprisonment for crimes of violence. Tonight Ethell the Frog examinesthe rise to power of the Piranhas, the methods they used to subjugate rival gangs and their subsequent tracking down and capture by the brilliant Superintendent Harry 'Snapper' Organs of Q Division.(photo of Eastend grotty house) Doug and Dinsdale Pirenha were born, on probation, in this small house in Kipling Road, Southwark, the eldest sons in a family of sixteen. Their father Arthur Piranha, a scrap-metal dealer and TV quizmaster, was well known to the police, and a devout Catholic. In January 1928 he had married Kitty Malone, (old wedding photo) an up-and-coming Eastend boxer. Doug was bornin February 1929 and Dinsdale two weeks later; and again a week after that. Their next door neighbour was Mrs April Simnel.
| Exterior in street; interviewer and Mrs Simnel. Line of gas men behind.
Mrs Simmel | Kipling Road was a typical sort of Eastend street, people were in and out of each other's houses with each other's property all day. They were a cheery lot.
Interviewer | Was it a terribly violent area?
Mrs Simmel | (laughs deprecatingly) Oh ho......yes. Cheerful and violent. I remember Doug was very keen on boxing, until he learned to walk, then he took up putting the boot in the groin. Oh he was very interested in that. His mother had such trouble getting him to come in for his tea. He'd be out there putting his little boot in, you know, bless him. You know kids were very different then. They didn't have their heads filled with all this Cartesian dualism.
| Cut to scool playground.
Voice Over | At the age of fifteen Doug and Dinsdale started attending the Ernest Pythagoras Primary School in Clerkenwell.
| Pan to show Anthony Viney and interviewer with stick mike.
Interviewer | Anthony Viney. You taught the Piranha brothers English. What do you remember most about them?
| He fails to point stick mike at Viney (graham) who answers. However, when the interviewer poses the next question he points the stick mike to Viney as he does so. This continues, with the mike always pointing to the one who is not talking while Viney relates a fascinating tale complete with large riveting gestures.
Interviewer | ...Anthoney Viney.
| Cut to presenter.
Presenter | When the Piranhas left school they were called up but were found by an Army Board to be too unstable even for National Service. Denied the opportunity to use their talents in the service of their country, they began to operate what they called 'The Operation'. They would select a victim and then threaten to beat him up if he paid the so-called protection money. Four months later they started another operation which the called 'The Other Operation'. In this racket they selected another victim and threatened not to beat him up if he didn't pay them. One month later they hit upon 'The Other Other Operation'. In this the victim was threatened that if he didn't pay them, they would beat him up. This for the Piranha brothers was the turning point.
| Cut to Superintendent Organs SUBTITLE: 'HARRY "SNAPPER" ORGANS'
Organs | Doug and Dinsdale Piranha now formed a gang, which the called 'The Gang' and used terror to take over night clubs, billiard halls, gaming casinos and race tracks. When they tried to take over the MCC they were for the only time in their lives, slit up a treat. As their empire spread however, we in Q Division were keeping tabs on their every move by reading the colour supplements.
Presenter | A small-time operator who fell foul of Dinsdale Piranha was Vince Snetterton-Lewis.
| Cut to Vince in a chair in a nasty flat.
Vince | Well one day I was sitting at home threatening the kids, and I looked out of the hole in the wall and sees this tank drive up and one of Dinsdale's boys gets out and he comes up, all nice and friendly like, and says Dinsdale wants to have a talk with me. So he chains me to the back of the tank and takes me for a scrape round to Dinsdale's. And Dinsdale's there in the conversation pit with Doug and Charles Paisley, the baby crusher, and a couple of film producers and a man they called 'Kierkegaard', who just sat there biting the heads of whippets and Dinsdale sayd 'I hear you've been a naughty boy Clement' and he splits me nostrils open and saws me leg off and pulls me liver out, and I said my name's not Clement and then he loses his temper and nails my head to the floor.
Interviewer | (off-screen) He nailed your head to the floor?
Vince | At first, yeah
| Cut to presenter.
Presenter | Another man who had his head nailed to the floor was Stig O' Tracey.
| Cut to another younger more cheerful man on sofa.
Interviewer | Stig, I've been told Dinsdale Piranha nailed your head to the floor.
Stig | No, no. Never, never. He was a smashing bloke. He used to give his mother flowers and that. He was like a brother to me.
Interviewer | But the police have film of Dinsdale actually nailing your head to the floor.
Stig | Oh yeah, well - he did that, yeah.
Interviewer | Why?
Stig | Well he had to, didn't he? I mean, be fair, there was nothing else he could do. I mean, I had transgressed the unwritten law.
Interviewer | What had you done?
Stig | Er... Well he never told me that. But he gave me his word that it was the case, and that's good enough for me with old Dinsy. I mean, he didn't want to nail my head to the floor. I had to insist. He wanted to let me off. There's nothing Dinsdale wouldn't do for you.
Interviewer | And you don't bear him any grudge?
Stig | A grudge! Old Dinsy? He was a real darling.
Interviewer | I understand he also nailed your wife's head to a coffee table. Isn't that right Mrs O' Tracey?
| Camera pans to show woman with coffee table nailed to head.
Mrs O' Tracey | Oh, no. No. No.
Stig | Yeah, well, he did do that. Yeah, yeah. He was a cruel man, but fair
| Cut back to Vince.
Interviewer | Vince, after he nailed your head to the floor, did you ever see him again
Vince | Yeah.....after that I used to go round his flat every Sunday lunchtime to apologize and we'd shake hands and then he'd nail my head to the floor
Interviewer | Every Sunday?
Vince | Yeah but he was very reasonable about it. I mean one Sunday when my parents were coming round for tea, I asked him if he'd mind very much not nailing my head to the floor that week and he agreed and just screwed my pelvis to a cake stand.
| Cut to man affixed to a coffee table and a standard lamp.
Man | He was the only friend I ever had.
| Cut to block of concrete with a man upside down with his head buried in it.
Block | I wouldn't head a word against him.
| Cut to a gravestone, which says: 'R.I.P. and Good Luck, Dinsdale'.
Voice | Lovely fella.
| Cut to presenter.
Presenter | Clearly Dinsdale inspired tremendous loyalty and terror amongst his business associates, but what was he really like?
| Cut to a bar.
Gloria | I walked out with Dinsdale on many occasions and found him a most charming and erudite companion. He was wont to introduce one to eminent persons, celebrated American singers, members of the aristocracy and other gang leaders.
Interviewer | (off screen) How had he met them?
Gloria | Through his work for charity. He took a warm interest in Boys' Clubs, Sailors' Homes, Choristers' Associations, Scouting Jamborees and of course the Household Cavalry.
Interviewer | Was there anything unusual about him?
Gloria | I should say not. Dinsdale was a perfectly normal person in every way. Except is as much as he was convinced that he was being watched by a giant hedgehog whom he referred to as Spiny Norman.
Interviewer | How big was Norman supposed to be?
Gloria | Normally he was wont to be about twelve feet from nose to tail, but when Dinsdale was very depressed Norman could be anything up to eight hundred yards long. When Norman was about, Dinsdale would go very quiet and his nose would swell up and his teeth would start moving about and he'd become very violent and claim that he'd laid Stanley Baldwin. Dinsdale was a gentleman. And what's more he knew how to treat a female impersonator.
| Cut to dark-suited loony in armchair. SUPERIMPOSED CAPTION: 'A CRIMINOLOGIST'
Criminologist | It is easy for us to judge Dinsdale Piranha too harshly. After all he only did what many of us simply dream of doing...(tic...controls himself) I'm sorry. After all a murderer is only an extroverted suicide. Dinsdale was a looney, but he was a happy looney. Lucky bastard.
Presenter | Most of the strange tales concern Dinsdale, but what about Doug? One man who met him was Luigi Vercotti.
| Cut to tatty office with desk and phone. Vercotti at deak.
Vercotti | Well, I had been running a successful escort agency - high class, no really, high class girls - we didn't have any of that. That was right out. And I decided. (phone rings on desk) Excuse me (he answers it) Hello......no, not now......shtoom...shtoom....right......yes, we'll have the watch ready for you at midnight.......the watch.....the Chinese watch....yes, right-oh, bye-bye mother (he replaces reciever) Anyway I decided then to open a high-class night club for the gentry at Biggleswade with International cuisine, cooking, top-line acts, and not a cheap clip joint for picking up tarts, that was right out, I deny that completely, and one night Dinsdale walked in with a couple of big lads, one of whom was carrying a tactical nuclear missile. They said I'd bought one of their fruit machines and would I pay for it.
Interviewer | How much did they want?
Vercotti | Three quarters of a million pounds. Then they went out.
Interviewer | Why didn't you call the police?
Vercotti | Well I had noticed that the lad with the thermo-nuclear device was the Chief Constable for the area. Anyway a week later they came back, said that the cheque had bounced and that I had to see Doug.
Interviewer | Doug?
Vercotti | Doug (takes a drink) I was terrified of him. Everyone was terrified of Doug. I've seen grown men pull their own heads off rather than see Doug. Even Dinsdale was frightened of Doug.
Interviewer | What did he do?
Vercotti | He used sarcasm. He knew all the tricks, dramatic irony, metaphor, bathos, puns, parody, litotes and satire.
| Cut to map.
Presenter | (voice over) By a combination of violence and sarcasm, the Piranha brothers by February 1966 controlled London and the South East. In February, though, Dinsdale made a big mistake.
| Cut back to bar and Gloria
Gloria | Latterly Dinsdale had become increasingly worried about Spiny Norman. He had come to the conclusion that Norman slept in an aeroplane hangar at Luton Airport.
Presenter | And so on February 22nd 1966, at Luton airport... (stock film of H-Bomb exploding) Even the police began to sit up and take notice.
| Cut to 'Snapper' Organs.
Organs | The Piranhas realized they had gone too far and that the hunt was on. They went into hiding and I decided on a subtle approach, viz some form of disguise, as the old helmet and boots are a bit of a giveaway. Luckily my years with Bristol Rep. stood me in good stead, as I assumed a bewildering variety of disguises. I tracked them to Cardiff, posing as the Reverend Smiler Egret. Hearing they'd gone back to London, I assumed the identity of a pork butcher, Brian Stoats. (photo of Organs disguised as a butcher) On my arrival in London, I discovered they had returned to Cardiff, I followed as Gloucester from 'King Lear'. (photo of Organs as Gloucester) Acting on a hunch I spent several months in Buenos Aires as Blind Pew, returning through the Panama Canal as Ratty, in 'Toad of Toad Hall'. (photo of Ratty) Back in Cardiff, I relived my triumph as Sancho Panza (photo) in 'Man of la Mancha' which the 'Bristol Evening Post' described as 'a glittering performance of rare perception', although the 'Bath Chronicle' was less than enthusiastic. In fact it gave me a right panning. I quote...
| Cut to press cutting, shich reads:
Voice Over | 'As for the performance of Superintendent Harry "Snapper" Organs as Sancho Panza, the audience were bemused by his high-pitched Welsh accent and intimidated by his abusive ad-libs.'
| Cut to letterhead of newspaper - 'The Western Daily News'.
Organs | (off screen) 'The 'Western Daily News' said......
Voice Over | 'Sancho Panza (Mr Organs) spoilt an otherwise impeccably choreographed rape scene by his unscheduled appearance and persistent cries of "What's all this then?".'
| Cut to back-stage-type dressing-room, with make-up mirrors.
Policeman | Never mind, Snapper, love, you can't win 'em all
Organs | True constable. Could I have my eye-liner please?
Second Policeman | Telegram for you, love.
Organs | Good-oh. Bet it's from Binkie.
Second Policeman | Those flowers are for Sergant Lauderdale - from the gentleman waiting outside
Organs | Oh good
| Knock, knock. Head comes round the door.
Man | Thirty seconds, superintendent.
Organs | Oh blimey, I'm on. Is me hat straight, constable?
Policeman | Oh it's fine
Organs | Right here we go then, Hawkins.
Policeman | Oh, merde, superintendent.
Organs | Good luck, then.
| Cut to exterior of Police Station. They come down the stairs and walk off along pavement. The city gent passes them doing his silly walk. Cut to a little newspaper seller
Newspaper Seller | Read all about it. Piranha brothers escape.
| Cut to suburban street: it completely clears very fast. Freeze frame on empty street. An enormous hedgehog higher that the houses comes into shot saying 'Dinsdale?' Roll credits, behind which we see the enormous hedgehog appearing in various well-known London locations.
Hedgehog | Dinsdale? Dinsdale? Dinsdale?
| Cut to John in cage as in opening shot.
John | Well, that's all for now and so until next week...(roars)
| Pan to next cage to show skeleton of 'It's' Man. Fade out.